@@ -191,12 +191,17 @@ int main(int argc, char *argv[])
 		else if (!strcmp(argv[i],"-nosound")){
 				strcpy(Config.Spu, "spunull.so");
 		}
-		else if (!strcmp(argv[i],"-bios")){
-		sprintf(Config.Bios, "/scph1001.bin");
-		}
+		else if(!strcmp(argv[i], "-bdir"))	sprintf(Config.BiosDir, "%s", argv[++i]);
+		else if(!strcmp(argv[i], "-bios"))	sprintf(Config.Bios, "%s", argv[++i]);
 		else if (!strcmp(argv[i],"-gles")){
 		strcpy(Config.Gpu, "gpuGLES.so");
 		}
+		else if (!strcmp(argv[i], "-cdda"))		Config.Cdda = 1;
+		else if (!strcmp(argv[i], "-xa"))		Config.Xa = 1;
+		else if (!strcmp(argv[i], "-rcnt"))		Config.RCntFix = 1 ;
+		else if (!strcmp(argv[i], "-sio"))		Config.Sio = 1;
+		else if (!strcmp(argv[i], "-spuirq"))	Config.SpuIrq = 1;
+		else if (!strcmp(argv[i], "-vsync"))	Config.VSyncWA = 1;
 		else if (!strcmp(argv[i], "-h") ||
 			 !strcmp(argv[i], "-help") ||
 			 !strcmp(argv[i], "--help")) {
