@@ -374,7 +374,7 @@ void maemoGLinit(){
 	EGLint numConfigs;
 	EGLint majorVersion;
 	EGLint minorVersion;
-#if defined(USE_X11)
+//#if defined(USE_X11)
 	enum
 	{
 	_NET_WM_STATE_REMOVE =0,
@@ -386,7 +386,7 @@ void maemoGLinit(){
 	XSetWindowAttributes	sWA;
 	unsigned int		    ui32Mask;
 	int			            i32Depth;
-#endif
+//#endif
 	
 	EGLint *attribList = NULL;
 	if (use_fsaa)
@@ -399,16 +399,10 @@ void maemoGLinit(){
 		attribList = attrib_list;
 	}
 
-#if defined(USE_X11)
 	pandora_driver_mode = MODE_X11; // TODO make configurable
-#else
-	pandora_driver_mode = MODE_RAW; // TODO make configurable
-#endif
+
 	
-    switch(pandora_driver_mode)
-            {            
-#if defined(USE_X11)
-        case MODE_X11:
+
             // Initializes the display and screen
             x11Display = XOpenDisplay( ":0" );
             if (!x11Display)
@@ -463,14 +457,7 @@ void maemoGLinit(){
             XSendEvent(x11Display, DefaultRootWindow(x11Display), False, SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 
             display = eglGetDisplay( (EGLNativeDisplayType)x11Display );
-            break;
-#endif
-        case MODE_RAW:
-        default:
-            display = eglGetDisplay( (EGLNativeDisplayType)0 );
-            break;
-    }
-
+          
 	if( display == EGL_NO_DISPLAY )
 	{
 		printf( "GLES EGL Error: GL No Display\n" );
@@ -492,18 +479,9 @@ void maemoGLinit(){
 		printf( "GLES EGL Error: eglCreateContext failed\n" );
 	}
 
-    switch(pandora_driver_mode)
-	{
-#if defined(USE_X11)
-        case MODE_X11:
-            surface = eglCreateWindowSurface( display, config, (EGLNativeDisplayType)x11Window, NULL );
-            break;
-#endif
-        case MODE_RAW:
-        default:
-            surface = eglCreateWindowSurface( display, config, (EGLNativeDisplayType)0, NULL );
-            break;
-	}
+
+            surface = eglCreateWindowSurface( display, config, (EGLNativeWindowType)x11Window, NULL );
+  	
 
     eglMakeCurrent( display, surface, surface, context );
     if (!TestEGLError("eglMakeCurrent"))
